==> layoutstudio-6.x-2.6.tar.gz: layoutstudio/MYTHEME/template.php <==
<?php
// $Id:

/**
 * Override or insert variables into all templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered (name of the .tpl.php file.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the page templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("page" in this case.)
 */
function MYTHEME_preprocess_page(&$variables, $hook) {
  // Add dimensions and other layout specific styles.
  $layout = theme_get_setting('layoutstudio_layout');
  $page_width = check_plain(theme_get_setting('layoutstudio_page_width'));
  $secondary_width = check_plain(theme_get_setting('layoutstudio_secondary_width'));
  $tertiary_width = check_plain(theme_get_setting('layoutstudio_tertiary_width'));
  $header_width = check_plain(theme_get_setting('layoutstudio_header_width'));
  $footer_width = check_plain(theme_get_setting('layoutstudio_footer_width'));

  // Width calculations for certain layouts
  if ($layout == "layout7") {
    $tertiary_width = $page_width - $secondary_width;
  }

	// Specify page width
	if ($header_width == 1 OR $footer_width == 1) {
		$data = '#container {width: '. $page_width .'px;}';
		if ($header_width == 1 && $footer_width == 1) {
			$data .= '#header .inside, #footer .inside {width: '. $page_width .'px; margin: 0 auto;}';
		}
		if ($header_width == 1 && $footer_width == 0) {
			$data .= '#header .inside {width: '. $page_width .'px; margin: 0 auto;}';
			$data .= '#footer {width: '. $page_width .'px; margin: 0 auto;}';
		}
		if ($header_width == 0 && $footer_width == 1) {
			$data .= '#footer .inside {width: '. $page_width .'px; margin: 0 auto;}';
			$data .= '#header {width: '. $page_width .'px; margin: 0 auto;}';
		}
	} 
	else {
		$data = '#page,#container {width: '. $page_width .'px;}';	
	}

	if ($layout != 'layout8') {

		if ($layout != 'layout7') {
      // Specify wrapper div settings
			$data .= '#wrapper {float: left; width: 100%;}';

		  // Specify primary div settings
			$data .= '#primary {';

      if ($layout == 'layout1') {
        $data .= '
          margin-left: '. $secondary_width .'px;
          margin-right: '. $tertiary_width .'px;
        ';
      }

      if ($layout == 'layout2') {
        $data .= '
          margin-left: '. $tertiary_width .'px;
          margin-right: '. $secondary_width .'px;
        ';
      }

      if ($layout == 'layout3' OR $layout == 'layout4') {
        $margin_right_width = $secondary_width + $tertiary_width;
        $data .= 'margin-right: '. $margin_right_width  .'px;';
      }

      if ($layout == 'layout5' OR $layout == 'layout6') {
        $margin_left_width = $secondary_width + $tertiary_width;
        $data .= 'margin-left: '. $margin_left_width  .'px;';
      }

			$data .= '}';
		}

		// Specify secondary div settings
		$data .= '
			#secondary {
				float: left;
				width: '. $secondary_width .'px;
		';

    if ($layout == 'layout1' OR $layout == 'layout5') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout == 'layout2' OR $layout == 'layout4') {
      $data .= 'margin-left: -'. $secondary_width .'px;';
    }
    if ($layout == 'layout3') {
      $margin_left_width = $secondary_width + $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout6') {
      $margin_left_width = $page_width - $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }

		$data .= '}';

		// Specify tertiary div settings
		$data .= '
			#tertiary {
				width: '. $tertiary_width .'px;
		';

    if ($layout == 'layout1' OR $layout == 'layout3') {
      $data .= 'margin-left: -'. $tertiary_width .'px;';
    }
    if ($layout == 'layout2') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout == 'layout4') {
      $margin_left_width = $secondary_width + $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout5') {
      $margin_left_width = $page_width - $secondary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout6') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout != 'layout7')	{
			$data .= 'float: left;';
		}
		if ($layout == 'layout7')	{
			$data .= 'float: right;';
		}

		$data .= '}';

		// Specify adjustments on pages with no secondary content
		if (!$variables['secondary_first'] && !$variables['secondary'] && !$variables['secondary_last']) {
			if ($layout == 'layout1') {
				$data .= '.no-secondary #primary {margin-left: 0;}';
			}
			if ($layout == 'layout2') {
				$data .= '.no-secondary #primary {margin-right: 0;}';
			}
			if ($layout == 'layout3' OR $layout == 'layout4') {
				$data .= '.no-secondary #primary {margin-right: '. $tertiary_width .'px;}';
			}
			if ($layout == 'layout4') {
				$data .= '.no-secondary #tertiary {margin-left: -'. $tertiary_width .'px;}';
			}
			if ($layout == 'layout5') {
				$data .= '.no-secondary #primary {margin-right: 0;}';
				$data .= '.no-secondary #primary {margin-left: '. $tertiary_width .'px;}';
			}
			if ($layout == 'layout6' OR $layout == 'layout5') {
				$data .= '.no-secondary #tertiary {margin-left: -'. $page_width .'px;}';
			}
			if ($layout == 'layout6') {
				$data .= '.no-secondary #primary {margin-left: '. $tertiary_width .'px;}';
			}
			if ($layout == 'layout7') {
				$data .= '.no-secondary #tertiary {float: none; width: auto;}';
			}
		}

		// Specify adjustments on pages with no tertiary content
		if (!$variables['tertiary_first'] && !$variables['tertiary'] && !$variables['tertiary_last']) {
			if ($layout == 'layout1') {
				$data .= '.no-tertiary #primary {margin-right: 0;};';
				$margin_left_width = $page_width - $secondary_width;
				$data .= '.no-tertiary #secondary {margin-left: -'. $margin_left_width .'px;}';
			}
			if ($layout == 'layout2') {
				$data .= '.no-tertiary #primary {margin-left: 0;};';
			}
			if ($layout == 'layout3') {
				$data .= '.no-tertiary #primary {margin-right: '. $secondary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $secondary_width .'px;}';
			}
			if ($layout == 'layout4') {
				$data .= '.no-tertiary #primary {margin-right: '. $tertiary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $tertiary_width .'px;}';
			}
			if ($layout == 'layout5') {
				$data .= '.no-tertiary #primary {margin-left: '. $secondary_width .'px;}';
			}
			if ($layout == 'layout6') {
				$data .= '.no-tertiary #primary {margin-left: '. $secondary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $page_width .'px;}';
			}
			if ($layout == 'layout7') {
				$data .= '.no-tertiary #secondary {float: none; width: auto;}';
			}
		}

		// Specify adjustments on pages with no secondary and no tertiary content
		if (!$variables['secondary_first'] && !$variables['secondary'] && !$variables['secondary_last'] && !$variables['tertiary_first'] && !$variables['tertiary'] && !$variables['tertiary_last']) {

			if ($layout == 'layout3' OR $layout == 'layout4' OR $layout == 'layout5') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $tertiary_width .'px;};';
			}
			if ($layout == 'layout4') {
				$data .= '.no-secondary-tertiary #tertiary {margin-left: -'. $tertiary_width .'px;};';
			}
			if ($layout == 'layout5' OR $layout == 'layout6') {
				$data .= '.no-secondary-tertiary #tertiary {margin-left: -'. $page_width .'px;};';
			}
			if ($layout == 'layout6') {
				$data .= '.no-secondary-tertiary #primary {margin-left: '. $tertiary_width .'px;};';
			}

			if ($layout == 'layout1') {
				$margin_left_width = $page_width - $secondary_width;
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $margin_left_width .'px;}';
			}
			if ($layout == 'layout3') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $secondary_width .'px;}';
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $secondary_width .'px;}';
			}
			if ($layout == 'layout4') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $tertiary_width .'px;}';
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $tertiary_width .'px;}';
			}
			if ($layout == 'layout5') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $secondary_width .'px;}';
			}
			if ($layout == 'layout6') {
				$data .= '.no-secondary-tertiary #primary {margin-left: '. $secondary_width .'px;}';
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $page_width .'px;}';
			}

			if ($layout != 'layout7') {
				$data .= '.no-secondary-tertiary #wrapper {float: none; width: auto;}';
				$data .= '.no-secondary-tertiary #primary {margin: 0;}';
			}
		}
	}

  $variables['layoutstudio_layout_styles'] = '<style type="text/css" media="all">' . $data . '</style>';
}

/**
 * Override or insert variables into the node templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("node" in this case.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_node(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the comment templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("comment" in this case.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_comment(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the block templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("block" in this case.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_block(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

==> layoutstudio-6.x-2.7.tar.gz: layoutstudio/MYTHEME/template.php <==
<?php
// $Id:

/**
 * Override or insert variables into all templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered (name of the .tpl.php file.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the page templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("page" in this case.)
 */
function MYTHEME_preprocess_page(&$variables, $hook) {
  // Add dimensions and other layout specific styles.
  $layout = theme_get_setting('layoutstudio_layout');
  $page_width = check_plain(theme_get_setting('layoutstudio_page_width'));
  $secondary_width = check_plain(theme_get_setting('layoutstudio_secondary_width'));
  $tertiary_width = check_plain(theme_get_setting('layoutstudio_tertiary_width'));
  $header_width = check_plain(theme_get_setting('layoutstudio_header_width'));
  $footer_width = check_plain(theme_get_setting('layoutstudio_footer_width'));

  // Width calculations for certain layouts
  if ($layout == "layout7") {
    $tertiary_width = $page_width - $secondary_width;
  }

	// Specify page width
	if ($header_width == 1 OR $footer_width == 1) {
		$data = '#container {width: '. $page_width .'px;}';
		if ($header_width == 1 && $footer_width == 1) {
			$data .= '#header .inside, #footer .inside {width: '. $page_width .'px; margin: 0 auto;}';
		}
		if ($header_width == 1 && $footer_width == 0) {
			$data .= '#header .inside {width: '. $page_width .'px; margin: 0 auto;}';
			$data .= '#footer {width: '. $page_width .'px; margin: 0 auto;}';
		}
		if ($header_width == 0 && $footer_width == 1) {
			$data .= '#footer .inside {width: '. $page_width .'px; margin: 0 auto;}';
			$data .= '#header {width: '. $page_width .'px; margin: 0 auto;}';
		}
	} 
	else {
		$data = '#page,#container {width: '. $page_width .'px;}';	
	}

	if ($layout != 'layout8') {

		if ($layout != 'layout7') {
      // Specify wrapper div settings
			$data .= '#wrapper {float: left; width: 100%;}';

		  // Specify primary div settings
			$data .= '#primary {';

      if ($layout == 'layout1') {
        $data .= '
          margin-left: '. $secondary_width .'px;
          margin-right: '. $tertiary_width .'px;
        ';
      }

      if ($layout == 'layout2') {
        $data .= '
          margin-left: '. $tertiary_width .'px;
          margin-right: '. $secondary_width .'px;
        ';
      }

      if ($layout == 'layout3' OR $layout == 'layout4') {
        $margin_right_width = $secondary_width + $tertiary_width;
        $data .= 'margin-right: '. $margin_right_width  .'px;';
      }

      if ($layout == 'layout5' OR $layout == 'layout6') {
        $margin_left_width = $secondary_width + $tertiary_width;
        $data .= 'margin-left: '. $margin_left_width  .'px;';
      }

			$data .= '}';
		}

		// Specify secondary div settings
		$data .= '
			#secondary {
				float: left;
				width: '. $secondary_width .'px;
		';

    if ($layout == 'layout1' OR $layout == 'layout5') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout == 'layout2' OR $layout == 'layout4') {
      $data .= 'margin-left: -'. $secondary_width .'px;';
    }
    if ($layout == 'layout3') {
      $margin_left_width = $secondary_width + $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout6') {
      $margin_left_width = $page_width - $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }

		$data .= '}';

		// Specify tertiary div settings
		$data .= '
			#tertiary {
				width: '. $tertiary_width .'px;
		';

    if ($layout == 'layout1' OR $layout == 'layout3') {
      $data .= 'margin-left: -'. $tertiary_width .'px;';
    }
    if ($layout == 'layout2') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout == 'layout4') {
      $margin_left_width = $secondary_width + $tertiary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout5') {
      $margin_left_width = $page_width - $secondary_width;
      $data .= 'margin-left: -'. $margin_left_width .'px;';
    }
    if ($layout == 'layout6') {
      $data .= 'margin-left: -'. $page_width .'px;';
    }
    if ($layout != 'layout7')	{
			$data .= 'float: left;';
		}
		if ($layout == 'layout7')	{
			$data .= 'float: right;';
		}

		$data .= '}';

		// Specify adjustments on pages with no secondary content
		if (!$variables['secondary_first'] && !$variables['secondary'] && !$variables['secondary_last']) {
			if ($layout == 'layout1') {
				$data .= '.no-secondary #primary {margin-left: 0;}';
			}
			if ($layout == 'layout2') {
				$data .= '.no-secondary #primary {margin-right: 0;}';
			}
			if ($layout == 'layout3' OR $layout == 'layout4') {
				$data .= '.no-secondary #primary {margin-right: '. $tertiary_width .'px;}';
			}
			if ($layout == 'layout4') {
				$data .= '.no-secondary #tertiary {margin-left: -'. $tertiary_width .'px;}';
			}
			if ($layout == 'layout5') {
				$data .= '.no-secondary #primary {margin-right: 0;}';
				$data .= '.no-secondary #primary {margin-left: '. $tertiary_width .'px;}';
			}
			if ($layout == 'layout6' OR $layout == 'layout5') {
				$data .= '.no-secondary #tertiary {margin-left: -'. $page_width .'px;}';
			}
			if ($layout == 'layout6') {
				$data .= '.no-secondary #primary {margin-left: '. $tertiary_width .'px;}';
			}
			if ($layout == 'layout7') {
				$data .= '.no-secondary #tertiary {float: none; width: auto;}';
			}
		}

		// Specify adjustments on pages with no tertiary content
		if (!$variables['tertiary_first'] && !$variables['tertiary'] && !$variables['tertiary_last']) {
			if ($layout == 'layout1') {
				$data .= '.no-tertiary #primary {margin-right: 0;}';
			}
			if ($layout == 'layout2') {
				$data .= '.no-tertiary #primary {margin-left: 0;}';
			}
			if ($layout == 'layout3') {
				$data .= '.no-tertiary #primary {margin-right: '. $secondary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $secondary_width .'px;}';
			}
			if ($layout == 'layout4') {
				$data .= '.no-tertiary #primary {margin-right: '. $secondary_width .'px;}';
			}
			if ($layout == 'layout5') {
				$data .= '.no-tertiary #primary {margin-left: '. $secondary_width .'px;}';
			}
			if ($layout == 'layout6') {
				$data .= '.no-tertiary #primary {margin-left: '. $secondary_width .'px;}';
				$data .= '.no-tertiary #secondary {margin-left: -'. $page_width .'px;}';
			}
			if ($layout == 'layout7') {
				$data .= '.no-tertiary #secondary {float: none; width: auto;}';
			}
		}

		// Specify adjustments on pages with no secondary and no tertiary content
		if (!$variables['secondary_first'] && !$variables['secondary'] && !$variables['secondary_last'] && !$variables['tertiary_first'] && !$variables['tertiary'] && !$variables['tertiary_last']) {

			if ($layout == 'layout3' OR $layout == 'layout4' OR $layout == 'layout5') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $tertiary_width .'px;}';
			}
			if ($layout == 'layout4') {
				$data .= '.no-secondary-tertiary #tertiary {margin-left: -'. $tertiary_width .'px;}';
			}
			if ($layout == 'layout5' OR $layout == 'layout6') {
				$data .= '.no-secondary-tertiary #tertiary {margin-left: -'. $page_width .'px;}';
			}
			if ($layout == 'layout6') {
				$data .= '.no-secondary-tertiary #primary {margin-left: '. $tertiary_width .'px;}';
			}

			if ($layout == 'layout1') {
				$margin_left_width = $page_width - $secondary_width;
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $margin_left_width .'px;}';
			}
			if ($layout == 'layout3') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $secondary_width .'px;}';
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $secondary_width .'px;}';
			}
			if ($layout == 'layout4') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $tertiary_width .'px;}';
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $tertiary_width .'px;}';
			}
			if ($layout == 'layout5') {
				$data .= '.no-secondary-tertiary #primary {margin-right: '. $secondary_width .'px;}';
			}
			if ($layout == 'layout6') {
				$data .= '.no-secondary-tertiary #primary {margin-left: '. $secondary_width .'px;}';
				$data .= '.no-secondary-tertiary #secondary {margin-left: -'. $page_width .'px;}';
			}

			if ($layout != 'layout7') {
				$data .= '.no-secondary-tertiary #wrapper {float: none; width: auto;}';
				$data .= '.no-secondary-tertiary #primary {margin: 0;}';
			}
		}
	}

  $variables['layoutstudio_layout_styles'] = '<style type="text/css" media="all">' . $data . '</style>';
}

/**
 * Override or insert variables into the node templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("node" in this case.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_node(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the comment templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("comment" in this case.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_comment(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */

/**
 * Override or insert variables into the block templates.
 *
 * @param $variables
 *   An array of variables to pass to the theme template.
 * @param $hook
 *   The name of the template being rendered ("block" in this case.)
 */
/* -- Delete this line if you want to use this function
function MYTHEME_preprocess_block(&$variables, $hook) {
  $variables['sample_variable'] = t('Lorem ipsum.');
}
// */
